@@ -2,6 +2,8 @@
 
 from typing import Final
 
+import static
+
 
 def locate_dir() -> str:
     """Return the location of the frontend files."""
@@ -9,4 +11,4 @@ def locate_dir() -> str:
 
 
 # The webcomponent name that loads the panel (main.ts)
-webcomponent_name: Final = "home-assistant-eltako-frontend"
+webcomponent_name: Final = "eltako-frontend"
